{% extends "wagtailadmin/base.html" %}
{% load i18n feature_flags %}
{% block titletag %}{% trans "Delete condition" as delete_str %} {{ delete_str }}: {{ condition_str }}{% endblock %}

{% block content %}
    {% trans "Delete condition" as delete_str %}
    {% include "wagtailadmin/shared/header.html" with title=delete_str subtitle=condition_str %}

    <form class="nice-padding" method="POST" action="{% url 'wagtailflags:delete_condition' flag.name condition_pk %}">
      {% csrf_token %}

      <p>Are you sure you want to delete this flag condition?</p>
      <input type="submit" value="Yes, delete it" class="button serious">

      <a href="{% url 'wagtailflags:flag_index' flag.name %}" class="button button-secondary">No, don't delete it</a>
    </form>
{% endblock %}
