{% extends "wagtailadmin/base.html" %}
{% load i18n wagtailadmin_tags %}
{% block titletag %}Create a flag{% endblock %}

{% block content %}
    {% trans "Create a flag" as create_flags_str %}
    {% include "wagtailadmin/shared/header.html" with title=create_flags_str icon="flag" %}

    <form class="nice-padding" method="POST" action="{% url 'wagtailflags:create_flag' %}">
        {% csrf_token %}
        <ul class="fields">
            {% for field in form %}
                {% include "wagtailadmin/shared/field.html" with field=field %}
            {% endfor %}
            <li>
                <input class="button action-save button-longrunning" type="submit" value="Save flag" />
                <a class="button bicolor button--icon" href="{% url 'wagtailflags:list' %}">{% icon name="cog" wrapped=1 %} Back to flags</a>
            </li>
        </ul>
    </form>
{% endblock %}
